#!/bin/bash

configureNic()
{
	nic=$nic2
	if [ $interfacesAll -lt 2 ]
	then
		nic=$nic1
		manageSnort "stop"
	fi

	ip=$(ip r | grep src | grep $nic | sed -e 's/.*src \([0-9\.]\+\)/\1/')

	if dialog --yesno "La IP actual es '$ip'\n¿Quieres cambiarla?" 7 40 
	then
		dialog --inputbox "Introduce la dirección IP" 10 31 2> $output
		ip=$(cat $output)
		dialog --inputbox "Introduce la mascara de red en formato XXXX.XXXX.XXXX.XXXX" 10 40 2> $output
		mask=$(cat $output)
		dialog --inputbox "Introduce la dirección IP de la puerta de enlace" 10 40 2> $output
		gateway=$(cat $output)
		if [ $interfacesAll -gt 1 ]
		then
			cat << EOF > /etc/network/interfaces
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

# The loopback network interface
auto lo $nic1 $nic2

iface lo inet loopback

iface $nic1 inet static
 address 169.254.0.2
 netmask 255.255.0.0

iface $nic2 inet static
 address $ip
 gateway $gateway
 netmask $mask
EOF
		else
			cat << EOF > /etc/network/interfaces
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

# The loopback network interface
auto lo $nic1

iface lo inet loopback

iface $nic1 inet static
 address $ip
 gateway $gateway
 netmask $mask
EOF
		fi
		/etc/init.d/networking restart
	fi
}

#selectNic()
#{
#	declare -i i=1
#	options=""
#	for interface in $(ifconfig -a | grep -e "eth" | grep -v lo | cut -d\  -f1)
#	do
#		options+="$i $interface "
#		i+=1
#	done
#	dialog --menu "Selecciona la tarjeta de red" 20 40 20 $options 2> $output
#	nic=$(cat $output)
#	configureNic $nic
#}

manageSnort()
{
	if [ $interfacesAll -gt 1 ]
	then
		case $1 in
			"start")
				dialog --infobox $(/etc/init.d/snort start)
			;;
			"stop")
				dialog --infobox $(/etc/init.d/snort stop)
			;;
			"restart")
				dialog --infobox $(/etc/init.d/snort restart)
			;;
		esac
	else
		dialog --infobox "Tan solo hay una tarjeta de red, no se puede ejecutar la sonda.\nConfigura la IP de gestión y habla con seguridad tecnológica para que lo revisen." 7 80
		/etc/init.d/snort stop
	fi
}

showMainMenu()
{
	dialog --menu "Menú principal" 20 40 20 1 "Configurar la IP de gestión" 2 "Parar la sonda" 3 "Iniciar la sonda" 4 "Reiniciar la sonda" \
	5 "Iniciar la captura de red" 6 "Parar la captura de red" 7 "Eliminar las capturas de red" \
	8 "Iniciar Ntop" 9 "Parar Ntop" 10 "Reiniciar Ntop" 2> $output
	option=$(cat $output)
	clear
	case $option in
		"1")
			#Configurar tarjeta de red
			configureNic
		;;
		"2")
			#Parar Snort
			manageSnort "stop"
		;;
		"3")
			#Iniciar Snort
			manageSnort "start"
		;;
		"4")
			#Reiniciar Snort
			manageSnort "restart"
		;;
		"5")
			if ! ps -e | grep tcpdump >& /dev/null
			then
				tcpdump -w $tcpdumps/$(date +"%d-%m_%H:%M").pcap -i $nic1 >& /dev/null &
			else
				dialog --infobox "Ya se está ejecutando una captura de red" 7 80
			fi
		;;
		"6")
			if ps -e | grep tcpdump >& /dev/null
			then
				kill $(pidof tcpdump)
			else
				dialog --infobox "No se está ejecutando ninguna captura de red" 7 80
			fi
		;;
		"7")
			if ! ps -e | grep tcpdump >& /dev/null
			then
				rm -f $tcpdumps/* >& /dev/null
			else
				dialog --infobox "Se está ejecutando una captura de red, detenla antes de eliminar las capturas" 7 80
			fi
		;;
		"8")
			dialog --infobox $(service ntop start)
		;;
		"9")
			dialog --infobox $(service ntop stop)
		;;
		"10")
			dialog --infobox $(service ntop restart)
		;;
	esac
}

setFirewall()
{
	iptables -A FORWARD -i $nic1 -o $nic2 -j DROP
	iptables -A FORWARD -i $nic2 -o $nic1 -j DROP

	iptables -A INPUT -p tcp --dport 22 -j ACCEPT
	iptables -A INPUT -p tcp --dport 3000 -j ACCEPT
	iptables -A INPUT -p tcp --dport 8089 -j ACCEPT

	#regla deny de entrada por defecto
	iptables -A INPUT -j DROP
}

setInterfaces()
{
	declare -i i=0
	for dev in $(ifconfig -a | grep -e "Ethernet" | cut -d\  -f1)
	do
		case $i in
			0)
				nic1=$dev
			;;
			1)
				nic2=$dev
			;;
		esac
		i+=1
	done
}

setInterfaces
ifconfig $nic1 up
setFirewall

tcpdumps="/home/tradmin/tcpdumps"

#crea el directorio para las capturas de red
mkdir $tcpdumps >& /dev/null

while true
do
	interfacesAll=$(ifconfig -a | grep -e "Ethernet" | wc -l)
	output=/tmp/output
	showMainMenu
done
